# MGSurvE: Mosquito Gene Surveillance Explorer

MGSurvE is a project oriented towards the optimization of traps' placement in complex heterogeneous landscapes in an effort to minimize the time to detection of genetic variants of interest.

![landscape](https://github.com/Chipdelmal/MGSurvE/raw/main/img/demo.jpg)

Please have a look at the [documentation](https://chipdelmal.github.io/MGSurvE/) for more info and our [https://pypi.org/project/MGSurvE/](pypi) package for installation and versions.

## Author

<img src="https://raw.githubusercontent.com/Chipdelmal/pyMSync/master/media/pusheen.jpg" height="130px" align="middle"><br>

* Lead: [Héctor M. Sánchez C.](https://chipdelmal.github.io/blog/)
* PIs: [David L. Smith](http://www.healthdata.org/about/david-smith), [John M. Marshall](https://publichealth.berkeley.edu/people/john-marshall/)
<br>

<img src="https://github.com/Chipdelmal/MGSurvE/raw/main/img/berkeley.jpg" height="25px"> <img src="https://github.com/Chipdelmal/MGSurvE/raw/main/img/IHME.jpg" height="25px">  <img src="https://github.com/Chipdelmal/MGSurvE/raw/main/img/UCIMI.png" height="25px"> <img src="https://github.com/Chipdelmal/MGSurvE/raw/main/img/IGI.png" height="25px"> <img src="https://github.com/Chipdelmal/MGSurvE/raw/main/img/DARPA.jpg" height="25px">

